/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.filter;

import org.w3c.dom.CharacterData;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: EmptyFilter.java,v 1.01 2005/12/21 13:24:17 Teletha Exp $
 */
public final class EmptyFilter extends AbstractPseudoFilter {

    /** The singleton instance. */
    public static final EmptyFilter SINGLETON = new EmptyFilter();

    /**
     * Avoid creating EmptyFilter instance.
     */
    private EmptyFilter() {
    }

    /**
     * @see org.trix.cuery.filter.Filter#accept(org.w3c.dom.Element)
     */
    public boolean accept(Element target) {
        // check child nodes
        if (!target.hasChildNodes()) {
            return true;
        }

        NodeList list = target.getChildNodes();

        for (int i = 0; i < list.getLength(); i++) {
            Node node = list.item(i);

            switch (node.getNodeType()) {
            case Node.CDATA_SECTION_NODE:
            case Node.TEXT_NODE:
                CharacterData data = (CharacterData) node;

                if (data.getLength() != 0) {
                    return false;
                }
                break;

            case Node.DOCUMENT_NODE:
            case Node.ELEMENT_NODE:
                return false;

            default:
                break;
            }
        }
        return true;
    }

    /**
     * @see org.trix.cuery.filter.AbstractPseudoFilter#getPseudoName()
     */
    protected String getPseudoName() {
        return "empty";
    }

}
